/****************************************************************************
 *	SDTP_types.h	
 *
 *	SDTP typesインクルードファイル
 *
 *  変更履歴
 *    2011.02.07  Ozawa   取得先を意識しない・・・（改修）
 *
 ****************************************************************************/
/* 2011.02.07 ADD by OZAWA start                                     */
/* 標準マクロ定義でOSを判定する場合は、以下の判定基準を使用する      */
/* #if sun で真ならSolaris、#if WIN32 が真ならWindows で             */
/* #else でLinuxとする。Linuxのみにしたい場合は、#if linux           */
/* が真でLinuxと判断する。                                           */
/* 2011.02.07 ADD by OZAWA ebd                                       */

#ifndef	_SDTP_TYPES_H_
#define	_SDTP_TYPES_H_

#include <sys/types.h>

/*** 2011.02.07 MOD by OZAWA start Solarisはstdint.hがないので修正 ***/
#if   sun
#include <sys/inttypes.h>
#elif WIN32
typedef __int8 int8_t;
typedef __int16 int16_t;
typedef __int32 int32_t;
typedef __int64 int64_t;
typedef unsigned __int8 uint8_t;
typedef unsigned __int16 uint16_t;
typedef unsigned __int32 uint32_t;
typedef unsigned __int64 uint64_t;
/*** 2011.02.07 DEL by OZAWA start sys/types.hに既に定義あり ***/
/* typedef unsigned long ssize_t; */
/*** 2011.02.07 DEL by OZAWA end   sys/types.hに既に定義あり ***/
#else
#include <stdint.h>
#endif
/*** 2011.02.07 MOD by OZAWA end   Solarisはstdint.hがないので修正 ***/

#ifndef	WIN32
#include <unistd.h>
#else
#define	sleep(s)
#define	close(fd)			closesocket(fd)
#define	read(fd, buf, len)	recv(fd, (char *)buf, len, 0)
#define	write(fd, buf, len)	send(fd, (char *)buf, len, 0)
#endif

#ifndef	WIN32
#include <netdb.h>
#include <arpa/inet.h>
#include <netinet/in.h> 
#include <netinet/tcp.h> 
#include <sys/select.h> 
#include <sys/socket.h> 
#else
#include <winsock2.h>
#endif

#ifndef FALSE
#define FALSE               0
#endif

#ifndef TRUE
#define TRUE                1
#endif

#define	ASIZE(a)		(sizeof(a)/sizeof((a)[0]))
#define	B(n)			(1<<(n))
#define	MK_I32(h, l)	(((h)<<16) | (l))
#define	MK_I16(h, l)	(((h)<< 8) | (l))

#ifdef	_DEBUG
#include <errno.h>
#define	_MSG( mod, ... )	\
	do {	\
		fprintf( stderr, "<%d>" mod "*%s:", errno, __FUNCTION__ );	\
		fprintf( stderr, __VA_ARGS__ );								\
	} while(0)
#else
#define	_MSG( mod, ... )
#endif

int SDTP_byte_order( void *p, int size, int order );
#define	sdt_ntohs(p)	SDTP_byte_order( p, sizeof(uint16_t), 'h' )
#define	sdt_ntohl(p)	SDTP_byte_order( p, sizeof(uint32_t), 'h' )
#define	sdt_htons(p)	SDTP_byte_order( p, sizeof(uint16_t), 'n' )
#define	sdt_htonl(p)	SDTP_byte_order( p, sizeof(uint32_t), 'n' )

#define	sdt_ntohS(p)	SDTP_byte_order( p, sizeof(uint16_t), 'H' )
#define	sdt_ntohL(p)	SDTP_byte_order( p, sizeof(uint32_t), 'H' )
#define	sdt_htonS(p)	SDTP_byte_order( p, sizeof(uint16_t), 'N' )
#define	sdt_htonL(p)	SDTP_byte_order( p, sizeof(uint32_t), 'N' )


#endif	/* _SDTP_TYPES_H_ */
