/************************************************************************
 * 
 *  SDT_all.h
 * 
 *    SDT_tlm_xxxx使用内部インクルードファイル
 * 
 *  変更履歴 
 *    2011.02.07  Ozawa    取得先を意識しない・・・（改修） 
 * 
 ************************************************************************/
#ifndef    _SDT_CLI_H_
#define    _SDT_CLI_H_

#include "SDTP_types.h"
#include "SDTP_all.h"

/********************************************************
 *    タイマー状態
 *******************************************************/
#define    SDT_ON    0x01    /* ＯＮ */
#define    SDT_OFF   0x00    /* ＯＦＦ */

/*** 2011.02.07 DEL by Ozawa  start ***/
#if 0  /* DELETE */
/********************************************************
 *    タイマー待ち時間
 *    (環境変数にて設定されていない場合は本値を使用する)
 *******************************************************/
#define    SDT_TIMER0VAL 20    /* タイマー０待ち時間 */
#endif
/*** 2011.02.07 DEL by Ozawa  end   ***/

/********************************************************
 *    終了理由コード
 *******************************************************/
#define    SDT_CLOSEOK         0x00    /* 正常終了 */
#define    SDT_CLOSEROUTE      0x11    /* 内部異常 */
#define    SDT_CLOSECNTLNG     0x21    /* 制御情報誤り */
#define    SDT_CLOSEMENT       0x31    /* メンテナンス */
#define    SDT_CLOSEFREE       0x32    /* サーバからの通信開放依頼による終了 */

/********************************************************
 *    終了モード
 *******************************************************/
#define    SDT_NORMALMODE    0x00    /* 通常終了モード */
#define    SDT_EXITMODE      0x01    /* 強制終了モード */
                                     /* 本モードの場合はリセットＰＤＵを送信する */
#define    SDT_CLOSEMODE     0x02    /* クローズ終了モード */
                                     /* 本モードの場合はソケットをクローズするのみ */

/********************************************************
 *    復帰コード
 *******************************************************/
#define    SDT_RCVFREEREQ    2        /* 通信解放依頼ＰＤＵ受信 */
/*** 2011.02.07 MOD by Ozawa  start エラーコード重複対処 ***/
#define    SDT_ENVERR         -20011        /* 環境変数取得エラー */
#define    SDT_ACCESSERR      -20012        /* ファイルアクセスエラー */
#define    SDT_SOCKFFMERR     -20013        /* SOCKFILE内容エラー */
#define    SDT_PUTENVERR      -20014        /* 環境変数設定エラー */
/*** 2011.02.07 MOD by Ozawa  end   エラーコード重複対処 ***/

/********************************************************
 *    ログファイル出力時のメッセージレベル
 *******************************************************/
#define    SDT_INFO   'I'        /* インフォメーション */
#define    SDT_WARN   'w'        /* 警告エラー */
#define    SDT_ERROR  'E'        /* 重大エラー */
#define    SDT_SYSERR 'S'        /* システムエラー */

/********************************************************
 *    ログファイル出力時のメッセージ
 *******************************************************/
#define SDT_I_OPENOK      "Received Open Responce PDU( OK ) And Open Session"
#define SDT_I_OPENNG      "Received Open Responce PDU( NG ) And Reject Open Session"
#define SDT_I_CLOSEOK     "Received Close Responce PDU( OK ) And Close Session"
#define SDT_I_RESET       "Close Session By Reset"
#define SDT_E_PARAM       "Input Parameter Error"
#define SDT_E_SOCKET      "Socket Create Error"
#define SDT_E_SOCKETOPT   "Set Socket Option Error"
#define SDT_E_CONNECT     "Connect Error"
#define SDT_E_BIND        "Bind Error"
#define SDT_E_LISTEN      "Listen Error"
#define SDT_E_SELECT      "Select Error"
#define SDT_E_ACCEPT      "Accept Error"
#define SDT_E_FORK        "Process Fork Error"
#define SDT_E_EXEC        "Process Exec Error"
#define SDT_E_SENDDATA    "PDU Send Error"
#define SDT_E_RECVDATA    "PDU Recv Error"
#define SDT_E_RECVWAIT    "PDU Recv-Wait Error"
#define SDT_E_TIMEOUT     "Time-Out Error"
#define SDT_E_SEQCNT      "Seq-Cnt Error"
#define SDT_E_SENDSEQERR  "Send-Seq-Cnt Error"
#define SDT_E_RECVSEQERR  "Recv-Seq-Cnt Error"
#define SDT_E_SYSDOWN     "Source-Process-Down"

/********************************************************
 *    ＣＰＮサービス種
 *******************************************************/
#define    SDT_PACKET    0x10    /* パケット個別指定 */
#define    SDT_VCDU      0x20    /* ＶＣＤＵ指定 */
#define    SDT_INSERT    0x40    /* インサートゾーン指定（未使用) */
#define    SDT_TRANS     0x80    /* トランスファーフレーム指定 */

/********************************************************
 *    ＣＰＮサービス情報構造体
 *******************************************************/
/*** 2011.02.07 MOD by Ozawa  start u_char => uint8_t***/
typedef struct CPN_DATA{
    uint8_t     vc_ch[2];    /* バーチャルチャネルＩＤ */
    uint8_t     pc_id[4];    /* パケットＩＤ */
}Cpn_data;

/********************************************************
 *    ＣＰＮサービス情報設定用構造体
 *******************************************************/
typedef struct CPN_DATA2{
    uint8_t     type;        /* ＣＰＮサービス種ＩＤ */
    uint8_t     vc_ch[2];    /* バーチャルチャネルＩＤ */
    uint8_t     pc_id[4];    /* パケットＩＤ */
}Cpn_data2;


#endif
